%define pypi_name  urllib3

%bcond_with check

Name:           python-%{pypi_name}
Summary:        Python HTTP library with thread-safe connection pooling, file post, and more
# https://urllib3.readthedocs.io/en/latest/v2-migration-guide.html
Version:        2.3.0
Release:        %mkrel 1
License:        MIT
Group:          Development/Python
Url:            https://urllib3.readthedocs.org/
Source0:        %{pypi_source}
Patch1:         urllib3-RECENT_DATE.patch
BuildArch:      noarch
BuildRequires:  python3-devel
%if %{with check}
BuildRequires:  python3dist(pytest)
%endif

%description
There are two critical features missing from the Python standard library:
Connection re-using/pooling and file posting. It's not terribly hard to
implement these yourself, but it's much easier to use a module that already did
the work for you.

The Python standard libraries urllib and urllib2 have little to do with each
other. They were designed to be independent and standalone, each solving a
different scope of problems, and urllib3 follows in a similar vein.

%package -n     python3-%{pypi_name}
Summary:        Python 3 HTTP library with thread-safe connection pooling, file post, and more
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:       rootcerts

%description -n python3-%{pypi_name}
There are two critical features missing from the Python standard library:
Connection re-using/pooling and file posting. It's not terribly hard to
implement these yourself, but it's much easier to use a module that already did
the work for you.

The Python standard libraries urllib and urllib2 have little to do with each
other. They were designed to be independent and standalone, each solving a
different scope of problems, and urllib3 follows in a similar vein.

%pyproject_extras_subpkg -n python3-%{pypi_name} brotli zstd socks h2

%prep
%autosetup -n %{pypi_name}-%{version} -p1

# relax reqs
sed -i -e 's/==/>=/g' dev-requirements.txt

%generate_buildrequires
%pyproject_buildrequires %{?with_check:dev-requirements.txt}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files urllib3

%if %{with check}
%check
%pytest -vv \
        --ignore=test/contrib/test_pyopenssl.py \
        --ignore=test/with_dummyserver \
        -k 'not test_ssl_read_timeout'
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE.txt
%doc CHANGES.rst README.md


%changelog
* Mon Feb 10 2025 daviddavid <daviddavid> 2.3.0-1.mga10
+ Revision: 2146643
- new version: 2.3.0

* Mon Jul 29 2024 wally <wally> 2.2.2-1.mga10
+ Revision: 2082823
- new version 2.2.2
- disable tests for now as we don't have new enough pytest

* Sun Jan 21 2024 wally <wally> 2.1.0-1.mga10
+ Revision: 2033346
- new version 2.1.0

* Fri Jan 05 2024 bcornec <bcornec> 1.26.18-4.mga10
+ Revision: 2027793
+ rebuild (emptylog)

* Mon Dec 25 2023 papoteur <papoteur> 1.26.18-3.mga10
+ Revision: 2021359
- fix requirement on pysocks

* Thu Dec 07 2023 wally <wally> 1.26.18-2.mga10
+ Revision: 2014804
- rebuild for py3.12
- build without %%check for py3.12 update

* Fri Oct 20 2023 daviddavid <daviddavid> 1.26.18-1.mga10
+ Revision: 1999814
- new version: 1.26.18
- remove merged upstream patches

* Mon May 08 2023 daviddavid <daviddavid> 1.26.15-1.mga9
+ Revision: 1956165
- new version: 1.26.15
- backport upstream testsuite fixes from 1.26 branch

* Sun Jan 22 2023 wally <wally> 1.26.14-1.mga9
+ Revision: 1934865
- new version 1.26.14

* Fri Sep 23 2022 luigiwalser <luigiwalser> 1.26.12-2.mga9
+ Revision: 1891848
- remove source1, bundled upstream now
- 1.26.12
+ neoclust <neoclust>
- New version  1.26.9

* Thu Mar 24 2022 umeabot <umeabot> 1.26.8-2.mga9
+ Revision: 1824621
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 1.26.8-1.mga9
+ Revision: 1771927
- new version 1.26.8
- rebuild for python3.10

* Mon Jul 26 2021 wally <wally> 1.26.6-1.mga9
+ Revision: 1737819
- new version 1.26.6

* Sun Jun 27 2021 luigiwalser <luigiwalser> 1.26.5-1.mga9
+ Revision: 1734038
- 1.26.5

* Thu Mar 18 2021 neoclust <neoclust> 1.26.2-3.mga9
+ Revision: 1704465
- Rebuild against python 3.9

* Sun Mar 14 2021 wally <wally> 1.26.2-2.mga9
+ Revision: 1702676
- rebuild for python 3.9

* Wed Dec 30 2020 luigiwalser <luigiwalser> 1.26.2-1.mga8
+ Revision: 1665948
- 1.26.2
- add patch from opensuse to remove dependency on external mock module

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1.25.11-1.mga8
+ Revision: 1651774
- 1.25.11

* Sat Oct 24 2020 daviddavid <daviddavid> 1.25.10-1.mga8
+ Revision: 1639018
- new version: 1.25.10, fixes CVE-2020-26137 (mga#27407)

* Sun Mar 29 2020 wally <wally> 1.25.8-1.mga8
+ Revision: 1562139
- new version 1.25.8

* Tue Feb 18 2020 umeabot <umeabot> 1.25.7-2.mga8
+ Revision: 1538194
- Mageia 8 Mass Rebuild

* Thu Nov 14 2019 daviddavid <daviddavid> 1.25.7-1.mga8
+ Revision: 1459997
- new version: 1.25.7

* Wed Nov 13 2019 daviddavid <daviddavid> 1.25.6-1.mga8
+ Revision: 1459720
- new version: 1.25.6

* Fri Oct 11 2019 tv <tv> 1.25.3-2.mga8
+ Revision: 1451709
- rebuild with python 3.8 + drop remaining py2 BRs

* Thu Sep 05 2019 wally <wally> 1.25.3-1.mga8
+ Revision: 1437554
- new version 1.25.3
- drop python2 support
- rebuild for python3.8

* Tue Aug 13 2019 luigiwalser <luigiwalser> 1.24.3-1.mga8
+ Revision: 1429098
- 1.24.3 (fixes CVE-2019-11236)

* Fri Apr 19 2019 daviddavid <daviddavid> 1.24.2-1.mga7
+ Revision: 1393510
- new version: 1.24.2, fixes CVE-2019-11324 (mga#23880)

* Mon Feb 18 2019 daviddavid <daviddavid> 1.24.1-3.mga7
+ Revision: 1368182
- add a conflict to ease upgrade mga6 -> mga7

* Sat Jan 05 2019 wally <wally> 1.24.1-2.mga7
+ Revision: 1349409
- rebuild for python3.7

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.24.1-1.mga7
+ Revision: 1346593
- 1.24.1

* Sat Oct 20 2018 daviddavid <daviddavid> 1.24-1.mga7
+ Revision: 1322985
- new version: 1.24
- rename python-urllib3 to python2-urllib3

* Fri Sep 21 2018 umeabot <umeabot> 1.22-3.mga7
+ Revision: 1290452
- Mageia 7 Mass Rebuild

* Thu Aug 03 2017 philippem <philippem> 1.22-2.mga7
+ Revision: 1134364
- rebuild for Python 3.6

* Mon Jul 31 2017 daviddavid <daviddavid> 1.22-1.mga7
+ Revision: 1133200
- new version: 1.22

* Wed Nov 02 2016 philippem <philippem> 1.18.1-1.mga6
+ Revision: 1064732
- update to 1.18.1, fix CVE-2016-9015, mga#19667

* Sat Sep 10 2016 luigiwalser <luigiwalser> 1.17-2.mga6
+ Revision: 1051358
- revert cp six that is not reverted since we do not have a check section

* Sat Sep 10 2016 luigiwalser <luigiwalser> 1.17-1.mga6
+ Revision: 1051310
- 1.17
- sync from spec fixes from fedora

* Tue May 03 2016 philippem <philippem> 1.15.1-1.mga6
+ Revision: 1009018
- update to 1.15.1

* Sun Feb 07 2016 philippem <philippem> 1.13.1-3.mga6
+ Revision: 942201
- fix dangling mga#17677 mga#17699

* Thu Feb 04 2016 philippem <philippem> 1.13.1-2.mga6
+ Revision: 936139
- fix danglin mga#17677

* Mon Dec 21 2015 daviddavid <daviddavid> 1.13.1-1.mga6
+ Revision: 913228
- new version: 1.13.1

* Tue Dec 15 2015 daviddavid <daviddavid> 1.13-1.mga6
+ Revision: 910641
- new version: 1.13

* Wed Oct 07 2015 philippem <philippem> 1.10.4-4.mga6
+ Revision: 887081
- rebuild for Python3.5
+ tv <tv>
- rebuild for python 3.5
- rebuild for python 3.5

* Mon Jul 20 2015 philippem <philippem> 1.10.4-1.mga6
+ Revision: 855810
- update to 1.10.4

* Wed Oct 15 2014 umeabot <umeabot> 1.9-5.mga5
+ Revision: 746753
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.9-4.mga5
+ Revision: 729957
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.9-3.mga5
+ Revision: 688404
- Mageia 5 Mass Rebuild

* Mon Jul 21 2014 ovitters <ovitters> 1.9-2.mga5
+ Revision: 655293
- really fix unbundling patch

* Mon Jul 21 2014 philippem <philippem> 1.9-1.mga5
+ Revision: 655269
- update to 1.9, add tests

* Mon Jul 21 2014 philippem <philippem> 1.8.3-2.mga5
+ Revision: 655034
- add missing requires

* Mon Jul 14 2014 philippem <philippem> 1.8.3-1.mga5
+ Revision: 651886
- update to 1.8.3

* Sat May 31 2014 pterjan <pterjan> 1.8.2-2.mga5
+ Revision: 629081
- Rebuild for new Python

* Sat May 24 2014 philippem <philippem> 1.8.2-1.mga5
+ Revision: 625296
- update to 1.8.2

* Tue Oct 22 2013 umeabot <umeabot> 1.7.1-3.mga4
+ Revision: 544254
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.7.1-2.mga4
+ Revision: 499682
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Oct 04 2013 nmartin <nmartin> 1.7.1-1.mga4
+ Revision: 491108
- Add correct unbundle patch which fixes also ssl import with Python 3
- update to new version 1.7.1

* Wed Aug 28 2013 philippem <philippem> 1.7-1.mga4
+ Revision: 472740
- update to 1.7, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 1.4-2.mga3
+ Revision: 379657
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Aug 03 2012 ovitters <ovitters> 1.4-1.mga3
+ Revision: 278165
- clean spec
- Import from Mandriva


* Tue Jul 17 2012 Lev Givon <lev@mandriva.org> 1.4-1
+ Revision: 810074
- Update to 1.4.

* Wed Apr 25 2012 Lev Givon <lev@mandriva.org> 1.3-1
+ Revision: 793427
- imported package python-urllib3

